@@ -127,10 +127,10 @@ class common(customwebDriverwait):
     def getAttribute(self, xpath,AttributeName):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if(elementPresense):
-                if(elementVisible):
-                    return elementVisible.get_attribute(AttributeName)
+                #if(elementVisible):
+                    return elementPresense.get_attribute(AttributeName)
         except Exception as error:
             raise error                  
     
@@ -146,10 +146,10 @@ class common(customwebDriverwait):
     def getDomAttribute(self, xpath,AttributeName):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if(elementPresense):
-                if(elementVisible):
-                    return elementVisible.get_dom_attribute(AttributeName)
+                #if(elementVisible):
+                    return elementPresense.get_dom_attribute(AttributeName)
         except Exception as error:
             raise error
 
@@ -165,10 +165,10 @@ class common(customwebDriverwait):
     def getProperty(self, xpath,PropertyName):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if(elementPresense):
-                if(elementVisible):
-                    return elementVisible.get_property(PropertyName)
+                #if(elementVisible):
+                    return elementPresense.get_property(PropertyName)
         except Exception as error:
             raise error             
     '''
@@ -626,11 +626,11 @@ class common(customwebDriverwait):
         try:
             actions = ActionChains(self.driver)
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
+                #if elementVisible:
                     #element = self.driver.find_element(By.XPATH, xpath)
-                    actions.scroll_to_element( elementVisible)
+                    actions.scroll_to_element( elementPresense)
                     actions.perform()
         except Exception as error:
             raise error
@@ -652,28 +652,28 @@ class common(customwebDriverwait):
     def get_Value_of_css_property(self,xpath,property_name):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.value_of_css_property(property_name)
+                #if elementVisible:
+                    return elementPresense.value_of_css_property(property_name)
         except Exception as error:
             raise error
     def get_Accessible_name(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.accessible_name
+                #if elementVisible:
+                    return elementPresense.accessible_name
         except Exception as error:
             raise error 
     def get_Aria_role(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.Aria_role
+                #if elementVisible:
+                    return elementPresense.Aria_role
         except Exception as error:
             raise error 
     '''Internal ID used by selenium.
@@ -688,19 +688,19 @@ class common(customwebDriverwait):
     def Get_internal_ID(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.id
+                #if elementVisible:
+                    return elementPresense.id
         except Exception as error:
             raise error
     def Get_location_of_Element(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.location
+                #if elementVisible:
+                    return elementPresense.location
         except Exception as error:
             raise error
     '''
@@ -712,22 +712,26 @@ class common(customwebDriverwait):
     def get_Scroll_location_of_Element(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.location_once_scrolled_into_view
+                #if elementVisible:
+                    return elementPresense.location_once_scrolled_into_view
         except Exception as error:
             raise error
+    def scroll_into_view_by_js(self,xpath):
+        elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath) 
+        if elementPresense:       
+            self.driver.execute_script("arguments[0].scrollIntoView(true);", self.driver.find_element_by_xpath(xpath))        
     '''
     Internal reference to the WebDriver instance this element was found from.
     '''        
     def get_Prent_of_Element(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.parent
+                #if elementVisible:
+                    return elementPresense.parent
         except Exception as error:
             raise error
     '''
@@ -736,10 +740,10 @@ class common(customwebDriverwait):
     def get_size_And_Location(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.rect
+                #if elementVisible:
+                    return elementPresense.rect
         except Exception as error:
             raise error
     def get_element_screenshot_as_base64(self,xpath,name:str):
@@ -778,37 +782,37 @@ class common(customwebDriverwait):
     def get_Element_shadow_root(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.shadow_root
+               # if elementVisible:
+                    return elementPresense.shadow_root
         except Exception as error:
             raise error
     def get_Element_size(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                        return elementVisible.size
+                #if elementVisible:
+                        return elementPresense.size
         except Exception as error:
             raise error
     def get_Element_tag_name(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.tag_name
+                #if elementVisible:
+                    return elementPresense.tag_name
         except Exception as error:
             raise error
     def get_Element_text(self,xpath):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located(xpath)
-            elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
+            #elementVisible = super().WaitFor_VisibilityOf_Element_Located(xpath)
             if elementPresense:
-                if elementVisible:
-                    return elementVisible.text
+                #if elementVisible:
+                    return elementPresense.text
         except Exception as error:
             raise error
     def __webElement_Screenshot_Location(self):
