@@ -51,7 +51,7 @@ class common_v2(customwebDriverwait):
             elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
             if(elementPresense):
                 if(elementVisible):
-                    elementPresense.click()
+                    elementVisible.click()
         except Exception as error:
             raise error            
 
@@ -61,7 +61,7 @@ class common_v2(customwebDriverwait):
             elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
             if(elementPresense):
                 if(elementVisible):
-                    elementPresense.clear()  
+                    elementVisible.clear()  
         except Exception as error:
             raise error              
     
@@ -125,9 +125,9 @@ class common_v2(customwebDriverwait):
     def getAttribute(self,locatorType:str,locator,AttributeName):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
             if(elementPresense):
-                if(elementVisible):
+                #if(elementVisible):
                     return elementPresense.get_attribute(AttributeName)
         except Exception as error:
             raise error                  
@@ -144,9 +144,9 @@ class common_v2(customwebDriverwait):
     def getDomAttribute(self,locatorType:str,locator,AttributeName):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
             if(elementPresense):
-                if(elementVisible):
+                #if(elementVisible):
                     return elementPresense.get_dom_attribute(AttributeName) 
         except Exception as error:
             raise error
@@ -163,9 +163,9 @@ class common_v2(customwebDriverwait):
     def getProperty(self,locatorType:str,locator,PropertyName):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
             if(elementPresense):
-                if(elementVisible):
+                #if(elementVisible):
                     return elementPresense.get_property(PropertyName)
         except Exception as error:
             raise error             
@@ -190,7 +190,7 @@ class common_v2(customwebDriverwait):
             elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)
             if(elementPresense):
                 if(elementVisible):
-                    return elementPresense.is_enabled()  
+                    return elementVisible.is_enabled()  
         except Exception as error:
             raise error
     '''
@@ -569,10 +569,10 @@ class common_v2(customwebDriverwait):
         try:
             actions = ActionChains(self.driver)
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                        actions.scroll_to_element( elementVisible)
+                    #if elementVisible:
+                       # actions.scroll_to_element( elementVisible)
                         actions.perform()
         except Exception as error:
             raise error
@@ -586,37 +586,37 @@ class common_v2(customwebDriverwait):
     def formSubmit(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                        elementVisible.submit()
+                   # if elementVisible:
+                        elementPresense.submit()
         except Exception as error:
             raise error
     def get_Value_of_css_property(self,locatorType:str,locator,property_name):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                        return elementVisible.value_of_css_property(property_name)
+                    #if elementVisible:
+                        return elementPresense.value_of_css_property(property_name)
         except Exception as error:
             raise error
     def get_Accessible_name(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                        return elementVisible.accessible_name
+                    #if elementVisible: 
+                        return elementPresense.accessible_name
         except Exception as error:
             raise error 
     def get_Aria_role(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                         return elementVisible.Aria_role
+                    #if elementVisible:
+                         return elementPresense.Aria_role
         except Exception as error:
             raise error 
     '''Internal ID used by selenium.
@@ -631,19 +631,19 @@ class common_v2(customwebDriverwait):
     def Get_internal_ID(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                        return elementVisible.id
+                    #if elementVisible: 
+                        return elementPresense.id
         except Exception as error:
             raise error
     def Get_location_of_Element(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                         return elementVisible.location
+                   # if elementVisible:
+                         return elementPresense.location
         except Exception as error:
             raise error
     '''
@@ -655,22 +655,22 @@ class common_v2(customwebDriverwait):
     def get_Scroll_location_of_Element(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                         return elementVisible.location_once_scrolled_into_view
+                    #if elementVisible: 
+                         return elementPresense.location_once_scrolled_into_view
         except Exception as error:
-            raise error
+            raise error          
     '''
     Internal reference to the WebDriver instance this element was found from.
     '''        
     def get_Prent_of_Element(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                        return elementVisible.parent
+                    #if elementVisible: 
+                        return elementPresense.parent
         except Exception as error:
             raise error
     '''
@@ -679,10 +679,10 @@ class common_v2(customwebDriverwait):
     def get_size_And_Location(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                            return elementVisible.rect
+                    #if elementVisible: 
+                            return elementPresense.rect
         except Exception as error:
             raise error
     def get_element_screenshot_as_base64(self,locatorType:str,locator,name:str):
@@ -721,37 +721,37 @@ class common_v2(customwebDriverwait):
     def get_Element_shadow_root(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                            return elementVisible.shadow_root
+                    #if elementVisible: 
+                            return elementPresense.shadow_root
         except Exception as error:
             raise error
     def get_Element_size(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible: 
-                            return elementVisible.size
+                    #if elementVisible: 
+                            return elementPresense.size
         except Exception as error:
             raise error
     def get_Element_tag_name(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                        return elementVisible.tag_name
+                    #if elementVisible:
+                        return elementPresense.tag_name
         except Exception as error:
             raise error
     def get_Element_text(self,locatorType:str,locator):
         try:
             elementPresense = super().WaitFor_PresenseOf_Element_Located_AnyLocatorType(locatorType,locator)
-            elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
+            #elementVisible = super().WaitFor_Visibility_of_Element_Located_AnyLocatorType(locatorType,locator)             
             if elementPresense:
-                    if elementVisible:
-                        return elementVisible.text
+                    #if elementVisible:
+                        return elementPresense.text
         except Exception as error:
             raise error
     def __webElement_Screenshot_Location(self):
